if Fence:HasModule('Browse') then return end

local L = AceLibrary("AceLocale-2.2"):new("Fence_Browse")
local l = AceLibrary("AceLocale-2.2"):new("Fence")
local abc = AceLibrary("Abacus-2.0")

-- Localization
L:RegisterTranslations("enUS", function() return {
		["Browse"] = true,
		["Show Bid"] = true,
		["Show Single-Price"] = true,
		["Single-Price Style"] = true,
		["Changes single-price style."] = true,
		["Bid"] = true,
        ["Changes bid style."] = true,
        ["Bid Style"] = true,
	}
end)

L:RegisterTranslations("deDE", function() return {
		["Browse"] = "Browse",
		["Show Bid"] = "Gebotanzeige",
		["Show Single-Price"] = "Einzelpreis-Anzeige",
		["Single-Price Style"] = "Einzelpreis-Stil",
		["Changes single-price style."] = "Stil f\195\188r Einzelpreis anpassen.",
		["Bid"] = "Gebot",
        ["Changes bid style."] = "Stil f\195\188r Gebote anpassen.",
        ["Bid Style"] = "Gebot-Stil"
	}
end)

local mod = Fence:NewModule("Browse")

Fence:RegisterDefaults('Browse', 'profile', {
	ShowPrice = true,
    ShowBid = true,
    PriceStyle = "short",
    BidStyle = "fade"
})

mod.db = Fence:AcquireDBNamespace("Browse")
	
	function mod:OnInitialize()
		       
		Fence.options.args.browse = {
			type = 'group',
			name = L["Browse"], aliases='br',
			desc = string.format(l["%s options"], L["Browse"]),
				args = {
					toggle = {
						type = 'toggle',
						name = L["Browse"],
						desc = string.format(l["Toggles %s function."], L["Browse"]),
						get = function() return Fence:IsModuleActive("Browse") end,
						set = function(v) Fence:ToggleModuleActive("Browse", v) end
					},
					showprice = {
						type = 'toggle',
						name = L["Show Single-Price"], aliases='sp',
						desc = string.format(l["Toggles %s function."], L["Show Single-Price"]),
						get = function() return self.db.profile.ShowPrice end,
						set = function(v) self.db.profile.ShowPrice = v end
					},
					pricestyle= {
						type = 'text',
						name = L["Single-Price Style"], aliases='ps',
						desc = L["Changes single-price style."],
						get = function() return self.db.profile.PriceStyle end,
						set = function(v) self.db.profile.PriceStyle= v end,
						validate = {"short", "full", "condensed"}
					},
					showbid = {
						type = 'toggle',
						name = L["Show Bid"], aliases='sb',
						desc = string.format(l["Toggles %s function."], L["Show Bid"]),
						get = function() return self.db.profile.ShowBid end,
						set = function(v) self.db.profile.ShowBid = v end
					},
  					bidstyle = {
						type = 'text',
						name = L["Bid Style"], aliases='bs',
						desc = L["Changes bid style."],
						get = function() return self.db.profile.BidStyle end,
						set = function(v) self.db.profile.BidStyle = v end,
                        validate = {"text", "fade"}
					}
				}
			}
	end

	function mod:OnEnable()
		self:RegisterEvent("AH_LOADED")
	end

	function mod:OnDisable()
		if self:IsHooked("AuctionFrameBrowse_Update") then self:Unhook("AuctionFrameBrowse_Update") end
	end

	function mod:AH_LOADED()
		self:Hook("AuctionFrameBrowse_Update", true)
		self:UnregisterEvent("AH_LOADED")
	end
	
	function mod:AuctionFrameBrowse_Update()
        self.hooks["AuctionFrameBrowse_Update"]()
		
        if not self.db.profile.ShowPrice and not self.db.profile.ShowBid then return end
        
       	local numBatchAuctions, totalAuctions = GetNumAuctionItems("list")   
        if numBatchAuctions == 0 then return end
        
		local offset = FauxScrollFrame_GetOffset(BrowseScrollFrame)
		local index, button, itemName, moneyFrame

        
		for i=1, NUM_BROWSE_TO_DISPLAY do
			index = offset + i + (NUM_AUCTION_ITEMS_PER_PAGE * AuctionFrameBrowse.page)

			local name, _, count, _, _, _, _, _, buyoutPrice, bidAmount, _, _ =  GetAuctionItemInfo("list", offset + i)
            if not name then return end
   			button = "BrowseButton"..i
            itemName = getglobal(button.."Name")		
            moneyFrame = getglobal(button.."MoneyFrame")
            moneyFrame:SetAlpha(1)

            local sM, spMoney, bidText, bT

			if self.db.profile.ShowPrice then
				if buyoutPrice > 0 and count > 1 then
					local ep = floor(buyoutPrice/count)
                    local ps = self.db.profile.PriceStyle
					if ps == "short" then
						spMoney = abc:FormatMoneyShort(ep, true)
						sM = strlen(abc:FormatMoneyShort(ep)) + 4
					elseif ps == "full" then
						spMoney = abc:FormatMoneyFull(ep, true)
						sM = strlen(abc:FormatMoneyFull(ep)) + 4
					elseif ps == "condensed" then
						spMoney = abc:FormatMoneyCondensed(ep, true)
						sM = strlen(abc:FormatMoneyCondensed(ep)) + 4
					end
                    if spMoney then spMoney = " ("..spMoney..") " end
                end
            end
            
			if self.db.profile.ShowBid then
				if bidAmount > 0 then 
					if self.db.profile.BidStyle == "text" then
						bidText = " - |cffffff00" .. L["Bid"] .. "|r"
						bT = strlen(L["Bid"]) + 3
					elseif self.db.profile.BidStyle == "fade" then
                        moneyFrame:SetAlpha(.4)
					end
				end
            end
                        
            if not sM then 
                sM = 0 
                spMoney = ""
            end
            
            if not bT then 
                bT = 0 
                bidText = ""
            end
            
            if strlen(name)+(sM+bT) > 40 then
                name = strsub(name,0,(strlen(name) - (sM+bT))).."..." 
            end
                  
            itemName:SetText(name..spMoney..bidText)
            
        end
    end
